Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(133)

Unified Diff: src/ia32/codegen-ia32.h

Issue 1750017: Port string keyed load IC improvements (r4444) to x64. (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: '' Created 10 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/ia32/codegen-ia32.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/ia32/codegen-ia32.h
===================================================================
--- src/ia32/codegen-ia32.h (revision 4526)
+++ src/ia32/codegen-ia32.h (working copy)
@@ -886,14 +886,15 @@
class StringHelper : public AllStatic {
public:
// Generates fast code for getting a char code out of a string
- // object at the given index. May bail out for three reasons (in the
+ // object at the given index. May bail out for four reasons (in the
// listed order):
// * Receiver is not a string (receiver_not_string label).
// * Index is not a positive smi (index_not_positive_smi label).
// * Some other reason (slow_case label). In this case it's
// guaranteed that the above conditions are not violated,
// e.g. it's safe to assume the receiver is a string and the
- // index is a positive smi.
+ // index is a non-negative smi < length.
// When successful, object, index, and scratch are clobbered.
// Otherwise, scratch and result are clobbered.
static void GenerateFastCharCodeAt(MacroAssembler* masm,
@@ -902,7 +903,8 @@
Register scratch,
Register result,
Label* receiver_not_string,
- Label* index_not_positive_smi,
+ Label* index_not_smi,
+ Label* index_out_of_range,
Label* slow_case);
// Generates code for creating a one-char string from the given char
« no previous file with comments | « no previous file | src/ia32/codegen-ia32.cc » ('j') | no next file with comments »
@@ -886,14 +886,15 @@
// listed order):
// * Receiver is not a string (receiver_not_string label).
- // * Index is not a positive smi (index_not_positive_smi label).
+ // * Index is not a smi (index_not_smi label).
+ // * Index is out of range (index_out_of_range).
// * Some other reason (slow_case label). In this case it's
// guaranteed that the above conditions are not violated,

Powered by Google App Engine
This is Rietveld 408576698